@@ -25,7 +25,7 @@ class TemplateContextMiddleware(object):
     """
     def process_template_response(self, request, response):
         if hasattr(response, 'context_data'):
-            if not 'channel' in response.context_data:
+            if 'channel' not in response.context_data:
                 site = get_current_site(request)
                 response.context_data['channel'] = Channel.objects\
                         .get_homepage(site=site or Site.objects.get(pk=1))
